from distutils.core import setup

setup(

       name          ='shili',
       version       ='1.0.0',
       py_modules    =['shili'],
       author        ='hfpython',
       author_email  ='hfpython@headfirstlabs.com',
       url           ='http://www.headfirstlabs.com',
       description   ='a simple printer of nested lists',

       )
